summaryrefslogtreecommitdiffstats
path: root/src/kernel/qapplication_x11.cpp
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2023-09-13 13:18:58 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2023-09-13 13:18:58 +0900
commit1ba13366a7a377d50b9e8df9044ce11d8209f98c (patch)
tree40765573bcccd42239475344141eb98d2ac5d45e /src/kernel/qapplication_x11.cpp
parent926102a455014e6ab308aaced19e32eed7ed4414 (diff)
downloadtqt3-1ba13366a7a377d50b9e8df9044ce11d8209f98c.tar.gz
tqt3-1ba13366a7a377d50b9e8df9044ce11d8209f98c.zip
Replace Q_EXPORT_*/Q_EXTERN defines with TQ_EXPORT_*/TQ_EXTERN
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'src/kernel/qapplication_x11.cpp')
-rw-r--r--src/kernel/qapplication_x11.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/src/kernel/qapplication_x11.cpp b/src/kernel/qapplication_x11.cpp
index c53ef91a..de2c62d2 100644
--- a/src/kernel/qapplication_x11.cpp
+++ b/src/kernel/qapplication_x11.cpp
@@ -38,7 +38,7 @@
**
**********************************************************************/
// ### 4.0: examine Q_EXPORT's below. The respective symbols had all
// been in use (e.g. in the KDE wm ) before the introduction of a version
// map. One might want to turn some of them into propert public API and
// provide a proper alternative for others. See also the exports in
@@ -192,7 +192,7 @@ static const char *appBTNCol = 0; // application btn color
static const char *mwGeometry = 0; // main widget geometry
static const char *mwTitle = 0; // main widget title
//Ming-Che 10/10
-Q_EXPORT char *qt_ximServer = 0; // XIM Server will connect to
+TQ_EXPORT char *qt_ximServer = 0; // XIM Server will connect to
static bool mwIconic = FALSE; // main widget iconified
//Ming-Che 10/10
static Display *appDpy = 0; // X11 application display
@@ -214,9 +214,9 @@ static GC* app_gc_tmp = 0; // temporary GC
static GC* app_gc_ro_m = 0; // read-only GC (monochrome)
static GC* app_gc_tmp_m = 0; // temporary GC (monochrome)
// symbols needed by extern TQXEmbed class
-Q_EXPORT Atom tqt_wm_protocols = 0; // window manager protocols
-Q_EXPORT Atom tqt_wm_delete_window = 0; // delete window protocol
-Q_EXPORT Atom tqt_wm_take_focus = 0; // take focus window protocol
+TQ_EXPORT Atom tqt_wm_protocols = 0; // window manager protocols
+TQ_EXPORT Atom tqt_wm_delete_window = 0; // delete window protocol
+TQ_EXPORT Atom tqt_wm_take_focus = 0; // take focus window protocol
Atom qt_qt_scrolldone = 0; // scroll synchronization
Atom qt_net_wm_context_help = 0; // context help
@@ -227,15 +227,15 @@ Atom qt_xa_clipboard = 0;
Atom qt_selection_property = 0;
Atom tqt_clipboard_sentinel = 0;
Atom qt_selection_sentinel = 0;
-Q_EXPORT Atom tqt_wm_state = 0;
+TQ_EXPORT Atom tqt_wm_state = 0;
Atom qt_wm_change_state = 0;
static Atom qt_settings_timestamp = 0; // TQt >=3 settings timestamp
static Atom qt_input_encoding = 0; // TQt desktop properties
static Atom qt_resource_manager = 0; // X11 Resource manager
Atom qt_sizegrip = 0; // sizegrip
Atom qt_wm_client_leader = 0;
-Q_EXPORT Atom tqt_window_role = 0;
-Q_EXPORT Atom tqt_sm_client_id = 0;
+TQ_EXPORT Atom tqt_window_role = 0;
+TQ_EXPORT Atom tqt_sm_client_id = 0;
Atom qt_xa_motif_wm_hints = 0;
Atom qt_cde_running = 0;
Atom qt_twin_running = 0;
@@ -328,7 +328,7 @@ static int xrandr_eventbase;
// TRUE if TQt is compiled w/ XRender support and XRender exists on the connected
// Display
-Q_EXPORT bool tqt_use_xrender = FALSE;
+TQ_EXPORT bool tqt_use_xrender = FALSE;
#ifndef TQT_NO_XSYNC
// True if SYNC extension exists on the connected display
@@ -347,7 +347,7 @@ static long qt_mode_switch_remove_mask = 0;
// flags for extensions for special Languages, currently only for RTL languages
static bool qt_use_rtl_extensions = FALSE;
-Q_EXPORT bool tqt_hebrew_keyboard_hack = FALSE;
+TQ_EXPORT bool tqt_hebrew_keyboard_hack = FALSE;
static Window mouseActWindow = 0; // window where mouse is
static int mouseButtonPressed = 0; // last mouse button pressed
@@ -406,7 +406,7 @@ typedef int (*QX11EventFilter) (XEvent*);
QX11EventFilter tqt_set_x11_event_filter(QX11EventFilter filter);
static QX11EventFilter qt_x11_event_filter = 0;
-Q_EXPORT QX11EventFilter tqt_set_x11_event_filter(QX11EventFilter filter)
+TQ_EXPORT QX11EventFilter tqt_set_x11_event_filter(QX11EventFilter filter)
{
QX11EventFilter old_filter = qt_x11_event_filter;
qt_x11_event_filter = filter;
@@ -425,16 +425,16 @@ static bool qt_x11EventFilter( XEvent* ev )
#if !defined(TQT_NO_XIM)
//XIM qt_xim = 0;
-Q_EXPORT XIMStyle qt_xim_style = 0;
-Q_EXPORT XIMStyle qt_xim_preferred_style = 0;
+TQ_EXPORT XIMStyle qt_xim_style = 0;
+TQ_EXPORT XIMStyle qt_xim_preferred_style = 0;
static XIMStyle xim_default_style = XIMPreeditCallbacks | XIMStatusNothing;
#endif
-Q_EXPORT int qt_ximComposingKeycode=0;
-Q_EXPORT TQTextCodec * qt_input_mapper = 0;
+TQ_EXPORT int qt_ximComposingKeycode=0;
+TQ_EXPORT TQTextCodec * qt_input_mapper = 0;
-Q_EXPORT Time tqt_x_time = CurrentTime;
-Q_EXPORT Time tqt_x_user_time = CurrentTime;
+TQ_EXPORT Time tqt_x_time = CurrentTime;
+TQ_EXPORT Time tqt_x_user_time = CurrentTime;
extern bool qt_check_clipboard_sentinel(); //def in qclipboard_x11.cpp
extern bool qt_check_selection_sentinel(); //def in qclipboard_x11.cpp
@@ -3908,7 +3908,7 @@ void tqt_leave_modal( TQWidget *widget )
}
-Q_EXPORT bool tqt_try_modal( TQWidget *widget, XEvent *event )
+TQ_EXPORT bool tqt_try_modal( TQWidget *widget, XEvent *event )
{
if (qt_xdnd_dragging) {
// allow mouse events while DnD is active
@@ -38,7 +38,7 @@
**
**********************************************************************/
-// ### 4.0: examine Q_EXPORT's below. The respective symbols had all
+// ### 4.0: examine TQ_EXPORT's below. The respective symbols had all
// been in use (e.g. in the KDE wm ) before the introduction of a version
// map. One might want to turn some of them into propert public API and